@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #include "statusbar.h"
@@ -19,12 +14,12 @@
 #include <KLocalizedString>
 #include <QStatusBar>
 #include <KSqueezedTextLabel>
-#include <KIconLoader>
 
 namespace Konversation
 {
 
     StatusBar::StatusBar(MainWindow* window)
+        : QObject (window)
     {
         m_window = window;
 
@@ -38,7 +33,7 @@ namespace Konversation
         // in the status bar. Which KSqueezedTextLabel doesn't.
         m_mainLabel->setSizePolicy(QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred, QSizePolicy::Label ));
         m_mainLabel->setObjectName(QStringLiteral("mainLabel"));
-        setMainLabelText(i18n("Ready."));
+        setMainLabelText(i18n("Ready"));
         m_mainLabel->setMinimumWidth(0);
 
         m_infoLabel = new QLabel(m_window->statusBar());
@@ -52,7 +47,8 @@ namespace Konversation
 
         m_sslLabel = new SSLLabel(m_window->statusBar());
         m_sslLabel->setObjectName(QStringLiteral("sslLabel"));
-        m_sslLabel->setPixmap(SmallIcon(QStringLiteral("security-high")));
+        const int smallIconSize = m_sslLabel->style()->pixelMetric(QStyle::PixelMetric::PM_SmallIconSize);
+        m_sslLabel->setPixmap(QIcon::fromTheme(QStringLiteral("security-high")).pixmap(smallIconSize));
         m_sslLabel->hide();
         m_sslLabel->setWhatsThis(i18n("All communication with the server is encrypted.  This makes it harder for someone to listen in on your communications."));
 
@@ -73,7 +69,7 @@ namespace Konversation
 
     void StatusBar::resetStatusBar()
     {
-        setMainLabelText(i18n("Ready."));
+        setMainLabelText(i18n("Ready"));
         setInfoLabelShown(false);
         setLagLabelShown(false);
         clearInfoLabel();
@@ -141,7 +137,7 @@ namespace Konversation
     {
         if (lagServer == m_window->getViewContainer()->getFrontServer())
         {
-            setMainLabelText(i18n("Ready."));
+            setMainLabelText(i18n("Ready"));
 
             QString lagString = lagServer->getServerName() + QStringLiteral(" - ");
 
@@ -223,8 +219,8 @@ namespace Konversation
         if (server == m_window->getViewContainer()->getFrontServer()
             && server->getUseSSL() && server->isConnected())
         {
-            disconnect(m_sslLabel,0,0,0);
-            connect(m_sslLabel,SIGNAL(clicked()),server,SLOT(showSSLDialog()));
+            disconnect(m_sslLabel,nullptr,nullptr,nullptr);
+            connect(m_sslLabel,&SSLLabel::clicked,server,&Server::showSSLDialog);
             m_sslLabel->setToolTip(server->getSSLInfo());
             m_sslLabel->show();
         }
@@ -234,7 +230,7 @@ namespace Konversation
 
     void StatusBar::removeSSLLabel()
     {
-        disconnect(m_sslLabel,0,0,0);
+        disconnect(m_sslLabel,nullptr,nullptr,nullptr);
         m_sslLabel->hide();
     }
 
